% find (positive) peaks of an 1-D array of values.
% usage: [p ip] = findpeaks(array [, n])
%     input:
%       array   :  1-D array
%       n       :  (optional) number of neighboring columns to
%                  use in comparision [Default 1]
%
%     output:
%       p       :  values of peaks
%       ip      :  indices of peaks
%
function [p ip] = findpeaks(a, nc)
    n = length(a);
    if (nargin < 2)
        nc = 1;
    endif

    barf = ones(n,1);
    for j = 1:nc
        barf &=[a(1+j:n) - a(1:n-j) < 0; ones(j,1)] & ...
               [ones(j,1); a(1:n-j) - a(1+j:n) < 0] ;
    end

    ip = find(barf);

    p = a(ip);
endfunction
