// -*- c++ -*-
// $Id$
/** \file
 * Octave module that smooths data by averaging adjacent channels.  This
 * should be pretty easy to implement in octave, but faster in c.  Mainly
 * though, this was one of the first octave modules that I ever wrote.
 *
 * Copyright 2005 Spencer Olson
 *
 * $Log$
 *
 */

#include <octave/oct.h>
#include <octave/pager.h>

DEFUN_DLD (smooth, args, ,
  "smoothed_Y  =  smooth(Y[,j])\n"
  "\n"
  "Smooth a set of data points by averaging adjacent channels.\n"
  "\n"
  "Copyright 1998-2005 Spencer Olson:\n"
  "\n"
  "Parameters:\n"
  "	Y	- Array of data points\n"
  "	j	- (optional) number of iterations to perform\n"
)
{
    if( args.length() < 1 ||
        args.length() > 2 ||
        !args(0).is_real_matrix() ) {
        print_usage("smooth");
        return octave_value();
    }

    ColumnVector y( args(0).vector_value () );
    const int y_lenm1 = y.length() - 1;

    int Niter = 1;
    if (args.length() == 2) Niter = args(1).int_value ();

    for (int j = 0; j < Niter; j++) {

        double y0 = y(0);
        for( int i = 0; i < y_lenm1; i++ ) {
            double ynew = ( y0 + 2.0 * y(i) + y(i + 1) ) / 4;
            y0 = y(i);
            y(i) = ynew;
        }//for

        /* do the last element. */
        y( y_lenm1 ) = ( y0 + 3.0* y( y_lenm1 ) ) / 4;
    }

    return octave_value(y);
}

